#
# spec file for package ensmallen
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020 Markus Kolb <novell+ensmallen@tower-net.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ensmallen
Version:        2.21.1
Release:        1.4
Summary:        Math optimization C++ library
License:        BSD-3-Clause AND MPL-2.0 AND BSL-1.0
Group:          Development/Languages/C and C++
URL:            https://ensmallen.org
Source0:        https://ensmallen.org/files/ensmallen-%{version}.tar.gz
BuildRequires:  armadillo-devel >= 9.800.6
BuildRequires:  cmake >= 3.3.2
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  make
Recommends:     armadillo-devel >= 9.800.6

%description
ensmallen provides a set of abstractions for writing an objective
function to optimize. It also provides a set of standard and
optimizers that can be used for mathematical optimization tasks.
These include full-batch gradient descent techniques, small-batch
techniques, gradient-free optimizers, and constrained optimization.

%package devel
Summary:        Math optimization C++ library
Group:          Development/Languages/C and C++

%description devel
ensmallen provides a set of abstractions for writing an objective
function to optimize. It also provides a set of standard and
optimizers that can be used for mathematical optimization tasks.
These include full-batch gradient descent techniques, small-batch
techniques, gradient-free optimizers, and constrained optimization.

%prep
%autosetup -p1

%build
%cmake -DENSMALLEN_CMAKE_DIR=%{_libdir}/cmake/ensmallen/
# Build the tests
%cmake_build ensmallen_tests

%install
%cmake_install
%fdupes %{buildroot}/%{_prefix}

%check
%ctest

%files devel
%license COPYRIGHT.txt
%license LICENSE.txt
%{_includedir}/ensmallen.hpp
%{_includedir}/ensmallen_bits
%{_libdir}/cmake/ensmallen/

%changelog
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 2.21.1:
  * Fix numerical precision issues for small-gradient L-BFGS
    scaling factor computations (#392).
  * Ensure the tests are built with optimisation enabled
  * Clarify return values for different callback types
  * Fix return types of callbacks
  * Minor cleanup for printing optimization reports via
    `Report()`
* Tue Nov 14 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.20.0:
  * Implementation of Active CMAES (gh#mlpack/ensmallen#367).
  * LBFGS: avoid generation of NaNs, and add checks for finite
    values (gh#mlpack/ensmallen#368).
  * Fix CNE test tolerances (gh#mlpack/ensmallen#360).
  * Rename SCD optimizer, to CD (gh#mlpack/ensmallen#379).
- Build and run tests.
* Fri Mar  3 2023 Dirk Müller <dmueller@suse.com>
- update to 2.19.1:
  * Avoid deprecation warnings in Armadillo 11.2+
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.19.0:
  * Added DemonSGD and DemonAdam optimizers
  * Fix bug with Adam-like optimizers not resetting when `resetPolicy` is `true`.
  * Add Yogi optimizer
  * Add AdaBelief optimizer
  * Add AdaSqrt optimizer
  * Bump check for minimum supported version of Armadillo
  * Update Catch2 to 2.13.8
  * Fix epoch timing output
  * Accelerate SGD test time
  * Fix potential infinite loop in CMAES
  * Fix SCD partial gradient test
  * Add gradient value clipping and gradient norm scaling callback
  * Remove superfluous CMake option to build the tests
  * Bump minimum Armadillo version to 9.800
  * Update Catch2 to 2.13.7
  * Remove redundant template argument for C++20 compatibility
  * Fix MOEAD test stability
* Sun Sep 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.17.0
  * CheckArbitraryFunctionTypeAPI extended for MOO support
  * Refactor NSGA2
  * Add MOEA-D/DE Optimizer
  * Add Das-Dennis weight initialization method
  * Add Dirichlet Weight Initialization
* Sat Mar 27 2021 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
* Fri Mar 26 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2.16.2
  * See: https://ensmallen.org/docs.html#ensmallen-2162-severely-dented-can-of-polyurethane
  * and skipped 2.16.1: https://ensmallen.org/docs.html#ensmallen-2161-severely-dented-can-of-polyurethane
* Wed Feb 17 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 2.16.0
  * See: https://ensmallen.org/docs.html#ensmallen-2160-severely-dented-can-of-polyurethane
- Drop _service file
- Fix cmake install
- Clean-up spec file
- Enable tests
* Sat Dec  5 2020 Markus Kolb <novell@tower-net.de>
- Update to version 2.15.1
  * See https://ensmallen.org/docs.html#ensmallen-2151-why-cant-i-manage-to-grow-any-plants
* Fri Jul  3 2020 Markus Kolb <novell@tower-net.de>
- Update to version 2.12.1
* Wed Mar 11 2020 Markus Kolb <novell@tower-net.de>
- Update to version 2.11.4
  * Updated 02-disable-ensmallen-test.patch
  * There is /usr/share/cmake/ensmallen
* Mon Nov  4 2019 Markus Kolb <novell@tower-net.de>
- Release ensmallen 2.10.3
